@@ -10,7 +10,7 @@ use IPC::Run qw/run timeout/;
 use Parallel::ForkManager;
 use File::ShareDir ":ALL";
 
-our $VERSION = '0.0.11'; # VERSION
+our $VERSION = '0.0.12'; # VERSION
 # ABSTRACT: map read to genome with bwa and soap
 
 
@@ -184,7 +184,7 @@ sub map {
   my ($infile, $indir, $outfile, $outdir) = ($self->infile, $self->indir, $self->outfile, $self->outdir);
   my ($genome, $tool, $process_sample) = ($self->genome, $self->tool, $self->process_sample);
   if ($indir) {
-    my @fqs = io($indir)->filter(sub {$_->filename =~/fastq|fq$/})->all_files;
+    my @fqs = io($indir)->filter(sub {$_->filename =~/fastq|fq|fastq\.gz|fq\.gz$/})->all_files;
     return 0 unless (@fqs);
     io($outdir)->mkpath unless -e $outdir;
     my $pm = Parallel::ForkManager->new($process_sample);
@@ -246,7 +246,7 @@ BioX::Map - map read to genome with bwa and soap
 
 =head1 VERSION
 
-version 0.0.11
+version 0.0.12
 
 =head1 SYNOPSIS
 
@@ -315,6 +315,8 @@ process of mapping software
 
 how many samples are processed parallel
 
+=head1 METHODS
+
 =head2 exist_index
 
 check whether genome index exists
