@@ -7,8 +7,9 @@ use MooX::Options prefer_commandline => 1, with_config_from_file => 1;
 use MooX::Cmd;
 use BioX::Map;
 use Types::Standard qw(Int Str Bool Enum);
+use Parallel::ForkManager;
 
-our $VERSION = '0.0.11'; # VERSION:
+our $VERSION = '0.0.12'; # VERSION:
 # ABSTRACT: a wrapper for mapping software
 
 
@@ -45,6 +46,16 @@ option bwa_suffix => (
 );
 
 
+option process => (
+  is      => 'ro',
+  format  => 's',
+  short   => 'p',
+  doc     => 'number of process will be used',
+  default => 2,
+
+);
+
+
 option outfile => (
   is        => 'ro',
   format    => 's',
@@ -65,7 +76,10 @@ sub execute {
   my @bwa_result = io($indir)->filter( sub {$_->filename =~/\.$bwa_suffix$/} )->all_files;
   $outfile = io($outfile);
   $outfile->print("samplename\tsoap0\tsoap1\tsoap2\tbwa0\tbwa1\tbwa2\n");
+  my $pm = Parallel::ForkManager->new($self->process);
+  DATA_LOOP:
   for my $sr (@soap_result) {
+    my $pid = $pm->start and next DATA_LOOP;
     $bm->tool("soap");
     my $filename = $sr->filename;
     say "###########sr: $sr ######filename: $filename";
@@ -77,8 +91,10 @@ sub execute {
     say "bwa result:$sr";
     my $b_r = $bm->statis_result("$sr");
     $sr =~s/\.$bwa_suffix//i;
-    $outfile->println(join "\t", $filename, @$s_r, @$b_r);
+    $outfile->lock->println(join "\t", $filename, @$s_r, @$b_r)->unlock;
+    $pm->finish;
   }
+  $pm->wait_all_children;
 }
 
 1;
@@ -95,7 +111,7 @@ BioX::Map::CLIS::Cmd::Compare - a wrapper for mapping software
 
 =head1 VERSION
 
-version 0.0.11
+version 0.0.12
 
 =head1 SYNOPSIS
 
@@ -120,6 +136,10 @@ suffix of all samples' soap result
 
 suffix of all samples' bwa result
 
+=head2 process
+
+number of process will be used
+
 =head2 outfile
 
 summary file
